@@ -55,9 +55,13 @@ def extend_pandas():
     _po.avg_win = stats.avg_win
     _po.avg_loss = stats.avg_loss
     _po.volatility = stats.volatility
+    _po.rolling_volatility = stats.rolling_volatility
     _po.implied_volatility = stats.implied_volatility
     _po.sharpe = stats.sharpe
+    _po.rolling_sharpe = stats.rolling_sharpe
     _po.sortino = stats.sortino
+    _po.rolling_sortino = stats.rolling_sortino
+    _po.omega = stats.omega
     _po.cagr = stats.cagr
     _po.rar = stats.rar
     _po.skew = stats.skew
@@ -66,6 +70,7 @@ def extend_pandas():
     _po.ulcer_index = stats.ulcer_index
     _po.ulcer_performance_index = stats.ulcer_performance_index
     _po.upi = stats.upi
+    _po.serenity_index = stats.serenity_index
     _po.risk_of_ruin = stats.risk_of_ruin
     _po.ror = stats.ror
     _po.value_at_risk = stats.value_at_risk
