@@ -251,7 +251,8 @@ def returns(returns, benchmark=None,
             fontname='Arial', lw=1.5,
             match_volatility=False, compound=True, cumulative=True,
             resample=None, ylabel="Cumulative Returns",
-            subtitle=True, savefig=None, show=True):
+            subtitle=True, savefig=None, show=True,
+            prepare_returns=True):
 
     title = 'Cumulative Returns' if compound else 'Returns'
     if benchmark is not None:
@@ -262,7 +263,9 @@ def returns(returns, benchmark=None,
         if match_volatility:
             title += ' (Volatility Matched)'
 
-    returns = _utils._prepare_returns(returns)
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
+
     benchmark = _utils._prepare_benchmark(benchmark, returns.index)
 
     fig = _core.plot_timeseries(returns, benchmark, title,
@@ -287,7 +290,8 @@ def log_returns(returns, benchmark=None,
                 fontname='Arial', lw=1.5,
                 match_volatility=False, compound=True, cumulative=True,
                 resample=None, ylabel="Cumulative Returns",
-                subtitle=True, savefig=None, show=True):
+                subtitle=True, savefig=None, show=True,
+                prepare_returns=True):
 
     title = 'Cumulative Returns' if compound else 'Returns'
     if benchmark is not None:
@@ -301,7 +305,9 @@ def log_returns(returns, benchmark=None,
         title += ' (Log Scaled'
     title += ')'
 
-    returns = _utils._prepare_returns(returns)
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
+
     benchmark = _utils._prepare_benchmark(benchmark, returns.index)
 
     fig = _core.plot_timeseries(returns, benchmark, title,
@@ -325,9 +331,12 @@ def daily_returns(returns,
                   grayscale=False, figsize=(10, 4),
                   fontname='Arial', lw=0.5,
                   log_scale=False, ylabel="Returns",
-                  subtitle=True, savefig=None, show=True):
+                  subtitle=True, savefig=None, show=True,
+                  prepare_returns=True):
+
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
 
-    returns = _utils._prepare_returns(returns)
     fig = _core.plot_timeseries(returns, None, 'Daily Returns',
                                 ylabel=ylabel,
                                 match_volatility=False,
@@ -350,7 +359,8 @@ def yearly_returns(returns, benchmark=None,
                    match_volatility=False,
                    log_scale=False, figsize=(10, 5), ylabel=True,
                    subtitle=True, compounded=True,
-                   savefig=None, show=True):
+                   savefig=None, show=True,
+                   prepare_returns=True):
 
     title = 'EOY Returns'
     if benchmark is not None:
@@ -359,11 +369,13 @@ def yearly_returns(returns, benchmark=None,
             benchmark, returns.index).resample('A').apply(
                 _stats.compsum).resample('A').last()
 
-    returns = _utils._prepare_returns(returns).resample('A')
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
+
     if compounded:
-        returns = returns.apply(_stats.compsum)
+        returns = returns.resample('A').apply(_stats.compsum)
     else:
-        returns = returns.apply(_df.cumsum)
+        returns = returns.resample('A').apply(_df.cumsum)
     returns = returns.resample('A').last()
 
     fig = _core.plot_returns_bars(returns, benchmark,
@@ -387,8 +399,11 @@ def yearly_returns(returns, benchmark=None,
 
 def distribution(returns, fontname='Arial', grayscale=False, ylabel=True,
                  figsize=(10, 6), subtitle=True, compounded=True,
-                 savefig=None, show=True):
-    returns = _utils._prepare_returns(returns)
+                 savefig=None, show=True,
+                 prepare_returns=True):
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
+
     fig = _core.plot_distribution(returns,
                                   fontname=fontname,
                                   grayscale=grayscale,
@@ -403,9 +418,12 @@ def distribution(returns, fontname='Arial', grayscale=False, ylabel=True,
 
 def histogram(returns, resample='M', fontname='Arial',
               grayscale=False, figsize=(10, 5), ylabel=True,
-              subtitle=True, compounded=True, savefig=None, show=True):
+              subtitle=True, compounded=True, savefig=None, show=True,
+              prepare_returns=True):
+
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
 
-    returns = _utils._prepare_returns(returns)
     if resample == 'W':
         title = "Weekly "
     elif resample == 'M':
@@ -453,8 +471,11 @@ def drawdown(returns, grayscale=False, figsize=(10, 5),
 def drawdowns_periods(returns, periods=5, lw=1.5, log_scale=False,
                       fontname='Arial', grayscale=False, figsize=(10, 5),
                       ylabel=True, subtitle=True, compounded=True,
-                      savefig=None, show=True):
-    returns = _utils._prepare_returns(returns)
+                      savefig=None, show=True,
+                      prepare_returns=True):
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
+
     fig = _core.plot_longest_drawdowns(returns,
                                        periods=periods,
                                        lw=lw,
@@ -475,9 +496,12 @@ def rolling_beta(returns, benchmark,
                  window2=252, window2_label="12-Months",
                  lw=1.5, fontname='Arial', grayscale=False,
                  figsize=(10, 3), ylabel=True,
-                 subtitle=True, savefig=None, show=True):
+                 subtitle=True, savefig=None, show=True,
+                 prepare_returns=True):
+
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
 
-    returns = _utils._prepare_returns(returns)
     benchmark = _utils._prepare_benchmark(benchmark, returns.index)
 
     fig = _core.plot_rolling_beta(returns, benchmark,
@@ -497,17 +521,18 @@ def rolling_beta(returns, benchmark,
 
 def rolling_volatility(returns, benchmark=None,
                        period=126, period_label="6-Months",
-                       trading_year_days=252,
+                       periods_per_year=252,
                        lw=1.5, fontname='Arial', grayscale=False,
                        figsize=(10, 3), ylabel="Volatility",
                        subtitle=True, savefig=None, show=True):
 
-    returns = _utils._prepare_returns(returns)
-    returns = returns.rolling(period).std() * _np.sqrt(trading_year_days)
+    returns = _stats.rolling_volatility(returns, period, periods_per_year)
 
     if benchmark is not None:
         benchmark = _utils._prepare_benchmark(benchmark, returns.index)
-        benchmark = benchmark.rolling(period).std() * _np.sqrt(trading_year_days)
+        returns = _stats.rolling_volatility(
+            returns, period, periods_per_year,
+            prepare_returns=False)
 
     fig = _core.plot_rolling_stats(returns, benchmark,
                                    hline=returns.mean(),
@@ -526,22 +551,19 @@ def rolling_volatility(returns, benchmark=None,
 
 def rolling_sharpe(returns, benchmark=None, rf=0.,
                    period=126, period_label="6-Months",
-                   trading_year_days=252,
+                   periods_per_year=252,
                    lw=1.25, fontname='Arial', grayscale=False,
                    figsize=(10, 3), ylabel="Sharpe",
                    subtitle=True, savefig=None, show=True):
 
-    returns = _utils._prepare_returns(returns, rf)
-    returns = returns.rolling(period).mean() / returns.rolling(period).std()
-    returns = returns * _np.sqrt(
-        1 if trading_year_days is None else trading_year_days)
+    returns = _stats.rolling_sharpe(
+        returns, rf, period, True, periods_per_year, )
 
     if benchmark is not None:
         benchmark = _utils._prepare_benchmark(benchmark, returns.index, rf)
-        benchmark = benchmark.rolling(
-            period).mean() / benchmark.rolling(period).std()
-        benchmark = benchmark * _np.sqrt(
-            1 if trading_year_days is None else trading_year_days)
+        benchmark = _stats.rolling_sharpe(
+            benchmark, rf, period, True, periods_per_year,
+            prepare_returns=False)
 
     fig = _core.plot_rolling_stats(returns, benchmark,
                                    hline=returns.mean(),
@@ -560,23 +582,19 @@ def rolling_sharpe(returns, benchmark=None, rf=0.,
 
 def rolling_sortino(returns, benchmark=None, rf=0.,
                     period=126, period_label="6-Months",
-                    trading_year_days=252,
+                    periods_per_year=252,
                     lw=1.25, fontname='Arial', grayscale=False,
                     figsize=(10, 3), ylabel="Sortino",
                     subtitle=True, savefig=None, show=True):
 
-    returns = _utils._prepare_returns(returns, rf)
-    returns = returns.rolling(period).mean() / \
-        returns[returns < 0].rolling(period).std()
-    returns = returns * _np.sqrt(
-        1 if trading_year_days is None else trading_year_days)
+    returns = _stats.rolling_sortino(
+        returns, rf, period, True, periods_per_year)
 
     if benchmark is not None:
         benchmark = _utils._prepare_benchmark(benchmark, returns.index, rf)
-        benchmark = benchmark.rolling(period).mean() / benchmark[
-            benchmark < 0].rolling(period).std()
-        benchmark = benchmark * _np.sqrt(
-            1 if trading_year_days is None else trading_year_days)
+        benchmark = _stats.rolling_sortino(
+            benchmark, rf, period, True, periods_per_year,
+            prepare_returns=False)
 
     fig = _core.plot_rolling_stats(returns, benchmark,
                                    hline=returns.mean(),
