@@ -40,26 +40,28 @@ except ImportError:
     pass
 
 
-def _get_trading_periods(trading_year_days=252):
-    half_year = _ceil(trading_year_days/2)
-    return trading_year_days, half_year
+def _get_trading_periods(periods_per_year=252):
+    half_year = _ceil(periods_per_year/2)
+    return periods_per_year, half_year
 
 
 def html(returns, benchmark=None, rf=0., grayscale=False,
          title='Strategy Tearsheet', output=None, compounded=True,
-         trading_year_days=252, download_filename='quantstats-tearsheet.html',
+         periods_per_year=252, download_filename='quantstats-tearsheet.html',
          figfmt='svg', template_path=None):
 
-    win_year, win_half_year = _get_trading_periods(trading_year_days)
-
     if output is None and not _utils._in_notebook():
         raise ValueError("`file` must be specified")
 
+    win_year, win_half_year = _get_trading_periods(periods_per_year)
+
     tpl = ""
     with open(template_path or __file__[:-4] + '.html') as f:
         tpl = f.read()
         f.close()
 
+    returns = _utils._prepare_returns(returns)
+
     date_range = returns.index.strftime('%e %b, %Y')
     tpl = tpl.replace('{{date_range}}', date_range[0] + ' - ' + date_range[-1])
     tpl = tpl.replace('{{title}}', title)
@@ -68,7 +70,8 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
     mtrx = metrics(returns=returns, benchmark=benchmark,
                    rf=rf, display=False, mode='full',
                    sep=True, internal="True",
-                   compounded=compounded)[2:]
+                   compounded=compounded,
+                   periods_per_year=periods_per_year)[2:]
     mtrx.index.name = 'Metric'
     tpl = tpl.replace('{{metrics}}', _html_table(mtrx))
     tpl = tpl.replace('<tr><td></td><td></td><td></td></tr>',
@@ -109,14 +112,16 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
     _plots.returns(returns, benchmark, grayscale=grayscale,
                    figsize=(8, 5), subtitle=False,
                    savefig={'fname': figfile, 'format': figfmt},
-                   show=False, ylabel=False, cumulative=compounded)
+                   show=False, ylabel=False, cumulative=compounded,
+                   prepare_returns=False)
     tpl = tpl.replace('{{returns}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.log_returns(returns, benchmark, grayscale=grayscale,
                        figsize=(8, 4), subtitle=False,
                        savefig={'fname': figfile, 'format': figfmt},
-                       show=False, ylabel=False, cumulative=compounded)
+                       show=False, ylabel=False, cumulative=compounded,
+                       prepare_returns=False)
     tpl = tpl.replace('{{log_returns}}', _embed_figure(figfile, figfmt))
 
     if benchmark is not None:
@@ -124,37 +129,42 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
         _plots.returns(returns, benchmark, match_volatility=True,
                        grayscale=grayscale, figsize=(8, 4), subtitle=False,
                        savefig={'fname': figfile, 'format': figfmt},
-                       show=False, ylabel=False, cumulative=compounded)
+                       show=False, ylabel=False, cumulative=compounded,
+                       prepare_returns=False)
         tpl = tpl.replace('{{vol_returns}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.yearly_returns(returns, benchmark, grayscale=grayscale,
                           figsize=(8, 4), subtitle=False,
                           savefig={'fname': figfile, 'format': figfmt},
-                          show=False, ylabel=False, compounded=compounded)
+                          show=False, ylabel=False, compounded=compounded,
+                          prepare_returns=False)
     tpl = tpl.replace('{{eoy_returns}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.histogram(returns, grayscale=grayscale,
                      figsize=(8, 4), subtitle=False,
                      savefig={'fname': figfile, 'format': figfmt},
-                     show=False, ylabel=False, compounded=compounded)
+                     show=False, ylabel=False, compounded=compounded,
+                     prepare_returns=False)
     tpl = tpl.replace('{{monthly_dist}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.daily_returns(returns, grayscale=grayscale,
                          figsize=(8, 3), subtitle=False,
                          savefig={'fname': figfile, 'format': figfmt},
-                         show=False, ylabel=False)
+                         show=False, ylabel=False,
+                         prepare_returns=False)
     tpl = tpl.replace('{{daily_returns}}', _embed_figure(figfile, figfmt))
 
     if benchmark is not None:
         figfile = _utils._file_stream()
         _plots.rolling_beta(returns, benchmark, grayscale=grayscale,
                             figsize=(8, 3), subtitle=False,
-                            window1=win_year, window2=win_half_year,
+                            window1=win_half_year, window2=win_year,
                             savefig={'fname': figfile, 'format': figfmt},
-                            show=False, ylabel=False)
+                            show=False, ylabel=False,
+                            prepare_returns=False)
         tpl = tpl.replace('{{rolling_beta}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
@@ -162,7 +172,7 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
                               figsize=(8, 3), subtitle=False,
                               savefig={'fname': figfile, 'format': figfmt},
                               show=False, ylabel=False, period=win_half_year,
-                              trading_year_days=win_year)
+                              periods_per_year=win_year)
     tpl = tpl.replace('{{rolling_vol}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
@@ -170,7 +180,7 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
                           figsize=(8, 3), subtitle=False,
                           savefig={'fname': figfile, 'format': figfmt},
                           show=False, ylabel=False, period=win_half_year,
-                          trading_year_days=win_year)
+                          periods_per_year=win_year)
     tpl = tpl.replace('{{rolling_sharpe}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
@@ -178,14 +188,15 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
                            figsize=(8, 3), subtitle=False,
                            savefig={'fname': figfile, 'format': figfmt},
                            show=False, ylabel=False, period=win_half_year,
-                           trading_year_days=win_year)
+                           periods_per_year=win_year)
     tpl = tpl.replace('{{rolling_sortino}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
     _plots.drawdowns_periods(returns, grayscale=grayscale,
                              figsize=(8, 4), subtitle=False,
                              savefig={'fname': figfile, 'format': figfmt},
-                             show=False, ylabel=False, compounded=compounded)
+                             show=False, ylabel=False, compounded=compounded,
+                             prepare_returns=False)
     tpl = tpl.replace('{{dd_periods}}', _embed_figure(figfile, figfmt))
 
     figfile = _utils._file_stream()
@@ -206,7 +217,8 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
     _plots.distribution(returns, grayscale=grayscale,
                         figsize=(8, 4), subtitle=False,
                         savefig={'fname': figfile, 'format': figfmt},
-                        show=False, ylabel=False, compounded=compounded)
+                        show=False, ylabel=False, compounded=compounded,
+                        prepare_returns=False)
     tpl = tpl.replace('{{returns_dist}}', _embed_figure(figfile, figfmt))
 
     tpl = _regex.sub(r'\{\{(.*?)\}\}', '', tpl)
@@ -223,7 +235,7 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
 
 def full(returns, benchmark=None, rf=0., grayscale=False,
          figsize=(8, 5), display=True, compounded=True,
-         trading_year_days=252):
+         periods_per_year=252):
 
     dd = _stats.to_drawdown_series(returns)
     dd_info = _stats.drawdown_details(dd).sort_values(
@@ -237,7 +249,8 @@ def full(returns, benchmark=None, rf=0., grayscale=False,
         iDisplay(iHTML('<h4>Performance Metrics</h4>'))
         iDisplay(metrics(returns=returns, benchmark=benchmark,
                          rf=rf, display=display, mode='full',
-                         compounded=compounded))
+                         compounded=compounded,
+                         periods_per_year=periods_per_year))
         iDisplay(iHTML('<h4>5 Worst Drawdowns</h4>'))
         if dd_info.empty:
             iDisplay(iHTML("<p>(no drawdowns)</p>"))
@@ -249,7 +262,8 @@ def full(returns, benchmark=None, rf=0., grayscale=False,
         print('[Performance Metrics]\n')
         metrics(returns=returns, benchmark=benchmark,
                 rf=rf, display=display, mode='full',
-                compounded=compounded)
+                compounded=compounded,
+                periods_per_year=periods_per_year)
         print('\n\n')
         print('[5 Worst Drawdowns]\n')
         if dd_info.empty:
@@ -262,38 +276,40 @@ def full(returns, benchmark=None, rf=0., grayscale=False,
 
     plots(returns=returns, benchmark=benchmark,
           grayscale=grayscale, figsize=figsize, mode='full',
-          trading_year_days=trading_year_days)
+          periods_per_year=periods_per_year)
 
 
 def basic(returns, benchmark=None, rf=0., grayscale=False,
           figsize=(8, 5), display=True, compounded=True,
-          trading_year_days=252):
+          periods_per_year=252):
 
     if _utils._in_notebook():
         iDisplay(iHTML('<h4>Performance Metrics</h4>'))
         metrics(returns=returns, benchmark=benchmark,
                 rf=rf, display=display, mode='basic',
-                compounded=compounded)
+                compounded=compounded,
+                periods_per_year=periods_per_year)
         iDisplay(iHTML('<h4>Strategy Visualization</h4>'))
     else:
         print('[Performance Metrics]\n')
         metrics(returns=returns, benchmark=benchmark,
                 rf=rf, display=display, mode='basic',
-                compounded=compounded)
+                compounded=compounded,
+                periods_per_year=periods_per_year)
 
         print('\n\n')
         print('[Strategy Visualization]\nvia Matplotlib')
 
     plots(returns=returns, benchmark=benchmark,
           grayscale=grayscale, figsize=figsize, mode='basic',
-          trading_year_days=trading_year_days)
+          periods_per_year=periods_per_year)
 
 
 def metrics(returns, benchmark=None, rf=0., display=True,
             mode='basic', sep=False, compounded=True,
-            trading_year_days=252, **kwargs):
+            periods_per_year=252, **kwargs):
 
-    win_year, _ = _get_trading_periods(trading_year_days)
+    win_year, _ = _get_trading_periods(periods_per_year)
 
     if isinstance(returns, _pd.DataFrame) and len(returns.columns) > 1:
         raise ValueError("`returns` must be a pandas Series, "
@@ -322,6 +338,8 @@ def metrics(returns, benchmark=None, rf=0., display=True,
 
     # pct multiplier
     pct = 100 if display or "internal" in kwargs else 1
+    if kwargs.get("as_pct", False):
+        pct = 100
 
     # return df
     dd = _calc_dd(df, display=(display or "internal" in kwargs))
@@ -340,7 +358,7 @@ def metrics(returns, benchmark=None, rf=0., display=True,
     metrics['Start Period'] = _pd.Series(s_start)
     metrics['End Period'] = _pd.Series(s_end)
     metrics['Risk-Free Rate %'] = _pd.Series(s_rf)
-    metrics['Time in Market %'] = _stats.exposure(df) * pct
+    metrics['Time in Market %'] = _stats.exposure(df, prepare_returns=False) * pct
 
     metrics['~'] = blank
 
@@ -350,43 +368,52 @@ def metrics(returns, benchmark=None, rf=0., display=True,
     else:
         metrics['Total Return %'] = (df.sum() * pct).map('{:,.2f}'.format)
 
-    metrics['CAGR%%'] = _stats.cagr(df, rf, compounded) * pct
+    metrics['CAGR﹪%'] = _stats.cagr(df, rf, compounded) * pct
 
     metrics['~~~~~~~~~~~~~~'] = blank
 
-    metrics['Sharpe'] = _stats.sharpe(df, rf, win_year, True, win_year)
-    metrics['Sortino'] = _stats.sortino(df, rf, win_year, True, win_year)
+    metrics['Sharpe'] = _stats.sharpe(df, rf, win_year, True)
+    metrics['Sortino'] = _stats.sortino(df, rf, win_year, True)
     metrics['Sortino/√2'] = metrics['Sortino'] / _sqrt(2)
+    metrics['Omega (0﹪)'] = _stats.omega(df, rf, 0., win_year)
 
     metrics['~~~~~~~~'] = blank
     metrics['Max Drawdown %'] = blank
     metrics['Longest DD Days'] = blank
 
     if mode.lower() == 'full':
-        ret_vol = _stats.volatility(df['returns'], win_year, True, win_year) * pct
+        ret_vol = _stats.volatility(
+            df['returns'], win_year, True, prepare_returns=False) * pct
         if "benchmark" in df:
-            bench_vol = _stats.volatility(df['benchmark'], win_year, True, win_year) * pct
+            bench_vol = _stats.volatility(
+                df['benchmark'], win_year, True, prepare_returns=False) * pct
             metrics['Volatility (ann.) %'] = [ret_vol, bench_vol]
-            metrics['R^2'] = _stats.r_squared(df['returns'], df['benchmark'])
+            metrics['R^2'] = _stats.r_squared(
+                df['returns'], df['benchmark'], prepare_returns=False)
         else:
             metrics['Volatility (ann.) %'] = [ret_vol]
 
-        metrics['Calmar'] = _stats.calmar(df)
-        metrics['Skew'] = _stats.skew(df)
-        metrics['Kurtosis'] = _stats.kurtosis(df)
+        metrics['Calmar'] = _stats.calmar(df, prepare_returns=False)
+        metrics['Skew'] = _stats.skew(df, prepare_returns=False)
+        metrics['Kurtosis'] = _stats.kurtosis(df, prepare_returns=False)
 
         metrics['~~~~~~~~~~'] = blank
 
-        metrics['Expected Daily %%'] = _stats.expected_return(df) * pct
+        metrics['Expected Daily %%'] = _stats.expected_return(
+            df, prepare_returns=False) * pct
         metrics['Expected Monthly %%'] = _stats.expected_return(
-            df, aggregate='M') * pct
+            df, aggregate='M', prepare_returns=False) * pct
         metrics['Expected Yearly %%'] = _stats.expected_return(
-            df, aggregate='A') * pct
-        metrics['Kelly Criterion %'] = _stats.kelly_criterion(df) * pct
-        metrics['Risk of Ruin %'] = _stats.risk_of_ruin(df)
+            df, aggregate='A', prepare_returns=False) * pct
+        metrics['Kelly Criterion %'] = _stats.kelly_criterion(
+            df, prepare_returns=False) * pct
+        metrics['Risk of Ruin %'] = _stats.risk_of_ruin(
+            df, prepare_returns=False)
 
-        metrics['Daily Value-at-Risk %'] = -abs(_stats.var(df) * pct)
-        metrics['Expected Shortfall (cVaR) %'] = -abs(_stats.cvar(df) * pct)
+        metrics['Daily Value-at-Risk %'] = -abs(_stats.var(
+            df, prepare_returns=False) * pct)
+        metrics['Expected Shortfall (cVaR) %'] = -abs(_stats.cvar(
+            df, prepare_returns=False) * pct)
 
     metrics['~~~~~~'] = blank
 
@@ -398,13 +425,13 @@ def metrics(returns, benchmark=None, rf=0., display=True,
     #     metrics['GPR (1Y)'] = _stats.gain_to_pain_ratio(df, rf, "A")
     metrics['~~~~~~~'] = blank
 
-    metrics['Payoff Ratio'] = _stats.payoff_ratio(df)
-    metrics['Profit Factor'] = _stats.profit_factor(df)
-    metrics['Common Sense Ratio'] = _stats.common_sense_ratio(df)
-    metrics['CPC Index'] = _stats.cpc_index(df)
-    metrics['Tail Ratio'] = _stats.tail_ratio(df)
-    metrics['Outlier Win Ratio'] = _stats.outlier_win_ratio(df)
-    metrics['Outlier Loss Ratio'] = _stats.outlier_loss_ratio(df)
+    metrics['Payoff Ratio'] = _stats.payoff_ratio(df, prepare_returns=False)
+    metrics['Profit Factor'] = _stats.profit_factor(df, prepare_returns=False)
+    metrics['Common Sense Ratio'] = _stats.common_sense_ratio(df, prepare_returns=False)
+    metrics['CPC Index'] = _stats.cpc_index(df, prepare_returns=False)
+    metrics['Tail Ratio'] = _stats.tail_ratio(df, prepare_returns=False)
+    metrics['Outlier Win Ratio'] = _stats.outlier_win_ratio(df, prepare_returns=False)
+    metrics['Outlier Loss Ratio'] = _stats.outlier_loss_ratio(df, prepare_returns=False)
 
     # returns
     metrics['~~'] = blank
@@ -427,26 +454,29 @@ def metrics(returns, benchmark=None, rf=0., display=True,
     d = today - _td(12*365/12)
     metrics['1Y %'] = comp_func(
         df[df.index >= _dt(d.year, d.month, d.day)]) * pct
+    d = today - _td(3*365)
     metrics['3Y (ann.) %'] = _stats.cagr(
-        df[df.index >= _dt(today.year-3, today.month, today.day)
+        df[df.index >= _dt(d.year, d.month, d.day)
            ], 0., compounded) * pct
+    d = today - _td(5*365)
     metrics['5Y (ann.) %'] = _stats.cagr(
-        df[df.index >= _dt(today.year-5, today.month, today.day)
+        df[df.index >= _dt(d.year, d.month, d.day)
            ], 0., compounded) * pct
+    d = today - _td(10*365)
     metrics['10Y (ann.) %'] = _stats.cagr(
-        df[df.index >= _dt(today.year-10, today.month, today.day)
+        df[df.index >= _dt(d.year, d.month, d.day)
            ], 0., compounded) * pct
     metrics['All-time (ann.) %'] = _stats.cagr(df, 0., compounded) * pct
 
     # best/worst
     if mode.lower() == 'full':
         metrics['~~~'] = blank
-        metrics['Best Day %'] = _stats.best(df) * pct
-        metrics['Worst Day %'] = _stats.worst(df) * pct
-        metrics['Best Month %'] = _stats.best(df, aggregate='M') * pct
-        metrics['Worst Month %'] = _stats.worst(df, aggregate='M') * pct
-        metrics['Best Year %'] = _stats.best(df, aggregate='A') * pct
-        metrics['Worst Year %'] = _stats.worst(df, aggregate='A') * pct
+        metrics['Best Day %'] = _stats.best(df, prepare_returns=False) * pct
+        metrics['Worst Day %'] = _stats.worst(df, prepare_returns=False) * pct
+        metrics['Best Month %'] = _stats.best(df, aggregate='M', prepare_returns=False) * pct
+        metrics['Worst Month %'] = _stats.worst(df, aggregate='M', prepare_returns=False) * pct
+        metrics['Best Year %'] = _stats.best(df, aggregate='A', prepare_returns=False) * pct
+        metrics['Worst Year %'] = _stats.worst(df, aggregate='A', prepare_returns=False) * pct
 
     # dd
     metrics['~~~~'] = blank
@@ -454,20 +484,21 @@ def metrics(returns, benchmark=None, rf=0., display=True,
         metrics[ix] = row
     metrics['Recovery Factor'] = _stats.recovery_factor(df)
     metrics['Ulcer Index'] = _stats.ulcer_index(df, rf)
+    metrics['Serenity Index'] = _stats.serenity_index(df, rf)
 
     # win rate
     if mode.lower() == 'full':
         metrics['~~~~~'] = blank
-        metrics['Avg. Up Month %'] = _stats.avg_win(df, aggregate='M') * pct
-        metrics['Avg. Down Month %'] = _stats.avg_loss(df, aggregate='M') * pct
-        metrics['Win Days %%'] = _stats.win_rate(df) * pct
-        metrics['Win Month %%'] = _stats.win_rate(df, aggregate='M') * pct
-        metrics['Win Quarter %%'] = _stats.win_rate(df, aggregate='Q') * pct
-        metrics['Win Year %%'] = _stats.win_rate(df, aggregate='A') * pct
+        metrics['Avg. Up Month %'] = _stats.avg_win(df, aggregate='M', prepare_returns=False) * pct
+        metrics['Avg. Down Month %'] = _stats.avg_loss(df, aggregate='M', prepare_returns=False) * pct
+        metrics['Win Days %%'] = _stats.win_rate(df, prepare_returns=False) * pct
+        metrics['Win Month %%'] = _stats.win_rate(df, aggregate='M', prepare_returns=False) * pct
+        metrics['Win Quarter %%'] = _stats.win_rate(df, aggregate='Q', prepare_returns=False) * pct
+        metrics['Win Year %%'] = _stats.win_rate(df, aggregate='A', prepare_returns=False) * pct
 
         if "benchmark" in df:
             metrics['~~~~~~~'] = blank
-            greeks = _stats.greeks(df['returns'], df['benchmark'], win_year)
+            greeks = _stats.greeks(df['returns'], df['benchmark'], win_year, prepare_returns=False)
             metrics['Beta'] = [str(round(greeks['beta'], 2)), '-']
             metrics['Alpha'] = [str(round(greeks['alpha'], 2)), '-']
 
@@ -520,9 +551,11 @@ def metrics(returns, benchmark=None, rf=0., display=True,
 
 def plots(returns, benchmark=None, grayscale=False,
           figsize=(8, 5), mode='basic', compounded=True,
-          trading_year_days=252):
+          periods_per_year=252):
 
-    win_year, win_half_year = _get_trading_periods(trading_year_days)
+    win_year, win_half_year = _get_trading_periods(periods_per_year)
+
+    returns = _utils._prepare_returns(returns)
 
     if mode.lower() != 'full':
         _plots.snapshot(returns, grayscale=grayscale,
@@ -538,36 +571,43 @@ def plots(returns, benchmark=None, grayscale=False,
 
     _plots.returns(returns, benchmark, grayscale=grayscale,
                    figsize=(figsize[0], figsize[0]*.6),
-                   show=True, ylabel=False)
+                   show=True, ylabel=False,
+                   prepare_returns=False)
 
     _plots.log_returns(returns, benchmark, grayscale=grayscale,
                        figsize=(figsize[0], figsize[0]*.5),
-                       show=True, ylabel=False)
+                       show=True, ylabel=False,
+                       prepare_returns=False)
 
     if benchmark is not None:
         _plots.returns(returns, benchmark, match_volatility=True,
                        grayscale=grayscale,
                        figsize=(figsize[0], figsize[0]*.5),
-                       show=True, ylabel=False)
+                       show=True, ylabel=False,
+                       prepare_returns=False)
 
     _plots.yearly_returns(returns, benchmark,
                           grayscale=grayscale,
                           figsize=(figsize[0], figsize[0]*.5),
-                          show=True, ylabel=False)
+                          show=True, ylabel=False,
+                          prepare_returns=False)
 
     _plots.histogram(returns, grayscale=grayscale,
                      figsize=(figsize[0], figsize[0]*.5),
-                     show=True, ylabel=False)
+                     show=True, ylabel=False,
+                     prepare_returns=False)
 
     _plots.daily_returns(returns, grayscale=grayscale,
                          figsize=(figsize[0], figsize[0]*.3),
-                         show=True, ylabel=False)
+                         show=True, ylabel=False,
+                         prepare_returns=False)
 
     if benchmark is not None:
         _plots.rolling_beta(returns, benchmark, grayscale=grayscale,
-                            window1=win_year, window2=win_half_year,
+                            window1=win_half_year, window2=win_year,
                             figsize=(figsize[0], figsize[0]*.3),
-                            show=True, ylabel=False)
+                            show=True, ylabel=False,
+                            prepare_returns=False)
 
     _plots.rolling_volatility(
         returns, benchmark, grayscale=grayscale,
@@ -584,7 +624,8 @@ def plots(returns, benchmark=None, grayscale=False,
 
     _plots.drawdowns_periods(returns, grayscale=grayscale,
                              figsize=(figsize[0], figsize[0]*.5),
-                             show=True, ylabel=False)
+                             show=True, ylabel=False,
+                             prepare_returns=False)
 
     _plots.drawdown(returns, grayscale=grayscale,
                     figsize=(figsize[0], figsize[0]*.4),
@@ -596,7 +637,8 @@ def plots(returns, benchmark=None, grayscale=False,
 
     _plots.distribution(returns, grayscale=grayscale,
                         figsize=(figsize[0], figsize[0]*.5),
-                        show=True, ylabel=False)
+                        show=True, ylabel=False,
+                        prepare_returns=False)
 
 
 def _calc_dd(df, display=True):
